==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/bg/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => 'Регистрация на <strong>акаунт</strong>',
    '<strong>Change</strong> Password' => '<strong>Смяна</strong> на парола',
    '<strong>Change</strong> your password' => '<strong>Променете</strong> паролата си',
    '<strong>Join</strong> the network' => '<strong>Присъединете се</strong> към мрежата',
    '<strong>Password</strong> changed!' => '<strong>Паролата</strong> е променена!',
    '<strong>Password</strong> recovery' => 'Възстановяване на <strong>парола</strong>',
    '<strong>Password</strong> recovery!' => 'Възстановяване на <strong>парола</strong>!',
    '<strong>Please</strong> sign in' => '<strong>Моля</strong> впишете се',
    '<strong>Registration</strong> successful!' => '<strong>Регистрацията</strong> е успешна!',
    '<strong>Sign</strong> up' => '<strong>Регистрирайте се</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Вашият акаунт</strong> е създаден успешно!',
    'Account' => 'Акаунт',
    'After activating your account by the administrator, you will receive a notification by email.' => 'След като активирате акаунта си от администратора, ще получите известие по имейл.',
    'Back' => 'Назад',
    'Change password' => 'Променете паролата',
    'Confirm' => 'Потвърждение',
    'Create Account' => 'Създай Акаунт',
    'Create account' => 'Създай акаунт',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Нямате акаунт? Присъединете се към мрежата, като въведете вашия имейл адрес.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Поради съображения за сигурност от вас се изисква да промените паролата си, за да получите достъп до платформата.',
    'Enter security code above' => 'Въведете кода за сигурност по-горе',
    'Forgot your password?' => 'Забравена парола?',
    'Go to login page' => 'Отидете на страницата за вписване',
    'Group' => 'Група',
    'Hello {displayName}' => 'Здравейте, {displayName}',
    'Hello {displayName},' => 'Здравейте, {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ако не използвате тази връзка в рамките на 24 часа, тя ще изтече.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ако вече сте член, моля, влезте с вашето потребителско име / имейл и парола.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Просто въведете вашия имейл адрес. Ще ви изпратим инструкции за възстановяване!',
    'Log out' => 'Излез от профила си',
    'Login' => 'Вход',
    'New user needs approval' => 'Новият потребител се нуждае от одобрение',
    'Password' => 'парола',
    'Password recovery' => 'Възстановяване на парола',
    'Password reset' => 'Нулиране на паролата',
    'Please check your email and follow the instructions!' => 'Моля, проверете имейла си и следвайте инструкциите!',
    'Please click on the link below to view request:' => 'Моля, кликнете върху връзката по-долу, за да видите заявката:',
    'Please enter the letters from the image.' => 'Моля, въведете буквите от изображението.',
    'Please login with your username/email and password.' => 'Моля, влезте с вашето потребителско име / имейл и парола.',
    'Please use the following link within the next day to reset your password.' => 'Моля, използвайте следната връзка в рамките на следващия ден, за да нулирате паролата си.',
    'Please wait' => 'Моля изчакайте',
    'Register' => 'Регистрирай се',
    'Registration successful' => 'Успешна регистрация',
    'Remember me' => 'Запомни ме',
    'Reset Password' => 'Нулиране на паролата',
    'Reset password' => 'Нулирайте паролата',
    'Sign in' => 'Впиши се',
    'To log in with your new account, click the button below.' => 'За да влезете с новия си акаунт, щракнете върху бутона по-долу.',
    'User or Password incorrect.' => 'Потребителско име или парола са неправилни.',
    'Username or Email' => 'потребителско име или парола',
    'Your email' => 'Твоят имейл',
    'Your password' => 'Твоята парола',
    'Your password has been successfully changed!' => 'Паролата ви е успешно променена!',
    'Your password is incorrect!' => 'Вашата парола е неправилна!',
    'a new user {displayName} needs approval.' => 'нов потребител {displayName} се нуждае от одобрение.',
    'back to home' => 'обратно към начална страница',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/bg/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => 'Регистрация на <strong>акаунт</strong>',
    '<strong>Change</strong> Password' => '<strong>Смяна</strong> на парола',
    '<strong>Change</strong> your password' => '<strong>Променете</strong> паролата си',
    '<strong>Join</strong> the network' => '<strong>Присъединете се</strong> към мрежата',
    '<strong>Password</strong> changed!' => '<strong>Паролата</strong> е променена!',
    '<strong>Password</strong> recovery' => 'Възстановяване на <strong>парола</strong>',
    '<strong>Password</strong> recovery!' => 'Възстановяване на <strong>парола</strong>!',
    '<strong>Please</strong> sign in' => '<strong>Моля</strong> впишете се',
    '<strong>Registration</strong> successful!' => '<strong>Регистрацията</strong> е успешна!',
    '<strong>Sign</strong> up' => '<strong>Регистрирайте се</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Вашият акаунт</strong> е създаден успешно!',
    'Account' => 'Акаунт',
    'After activating your account by the administrator, you will receive a notification by email.' => 'След като активирате акаунта си от администратора, ще получите известие по имейл.',
    'Back' => 'Назад',
    'Change password' => 'Променете паролата',
    'Confirm' => 'Потвърждение',
    'Create Account' => 'Създай Акаунт',
    'Create account' => 'Създай акаунт',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Нямате акаунт? Присъединете се към мрежата, като въведете вашия имейл адрес.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Поради съображения за сигурност от вас се изисква да промените паролата си, за да получите достъп до платформата.',
    'Forgot your password?' => 'Забравена парола?',
    'Go to login page' => 'Отидете на страницата за вписване',
    'Group' => 'Група',
    'Hello {displayName}' => 'Здравейте, {displayName}',
    'Hello {displayName},' => 'Здравейте, {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ако не използвате тази връзка в рамките на 24 часа, тя ще изтече.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ако вече сте член, моля, влезте с вашето потребителско име / имейл и парола.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Просто въведете вашия имейл адрес. Ще ви изпратим инструкции за възстановяване!',
    'Log out' => 'Излез от профила си',
    'Login' => 'Вход',
    'New user needs approval' => 'Новият потребител се нуждае от одобрение',
    'Password' => 'парола',
    'Password recovery' => 'Възстановяване на парола',
    'Password reset' => 'Нулиране на паролата',
    'Please click on the link below to view request:' => 'Моля, кликнете върху връзката по-долу, за да видите заявката:',
    'Please login with your username/email and password.' => 'Моля, влезте с вашето потребителско име / имейл и парола.',
    'Please use the following link within the next day to reset your password.' => 'Моля, използвайте следната връзка в рамките на следващия ден, за да нулирате паролата си.',
    'Please wait' => 'Моля изчакайте',
    'Register' => 'Регистрирай се',
    'Remember me' => 'Запомни ме',
    'Reset Password' => 'Нулиране на паролата',
    'Reset password' => 'Нулирайте паролата',
    'Sign in' => 'Впиши се',
    'To log in with your new account, click the button below.' => 'За да влезете с новия си акаунт, щракнете върху бутона по-долу.',
    'User or Password incorrect.' => 'Потребителско име или парола са неправилни.',
    'Username or Email' => 'потребителско име или парола',
    'Your email' => 'Твоят имейл',
    'Your password' => 'Твоята парола',
    'Your password has been successfully changed!' => 'Паролата ви е успешно променена!',
    'Your password is incorrect!' => 'Вашата парола е неправилна!',
    'a new user {displayName} needs approval.' => 'нов потребител {displayName} се нуждае от одобрение.',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
];
